summaryrefslogtreecommitdiffstats
path: root/macosx/tkMacOSXEmbed.c
diff options
context:
space:
mode:
authorjan.nijtmans <nijtmans@users.sourceforge.net>2022-02-01 21:50:55 (GMT)
committerjan.nijtmans <nijtmans@users.sourceforge.net>2022-02-01 21:50:55 (GMT)
commit1ebb0c9d23b20f48bb8d5cc30f30532c99823731 (patch)
tree639f805d8747720a68d33f6fb1db835bfaf70bee /macosx/tkMacOSXEmbed.c
parent0bffbe8dfe9cd138fc970a3b8d026558f2f57847 (diff)
downloadtk-1ebb0c9d23b20f48bb8d5cc30f30532c99823731.zip
tk-1ebb0c9d23b20f48bb8d5cc30f30532c99823731.tar.gz
tk-1ebb0c9d23b20f48bb8d5cc30f30532c99823731.tar.bz2
Fix Tk_Get3BorderColors() signature. Add documentation, created by René Zaumseil
Diffstat (limited to 'macosx/tkMacOSXEmbed.c')
-rw-r--r--macosx/tkMacOSXEmbed.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/macosx/tkMacOSXEmbed.c b/macosx/tkMacOSXEmbed.c
index a5de2f1..3f5d0a4 100644
--- a/macosx/tkMacOSXEmbed.c
+++ b/macosx/tkMacOSXEmbed.c
@@ -644,7 +644,7 @@ TkpRedirectKeyEvent(
* this procedure will return either one, given the other.
*
* Results:
* If winPtr is a container, the return value is the token for the
* embedded window, and vice versa. If the "other" window isn't in this
* process, NULL is returned.
*
@@ -656,7 +656,7 @@ TkpRedirectKeyEvent(
Tk_Window
Tk_GetOtherWindow(
- Tk_Window winPtr) /* Tk's structure for a container or embedded
+ Tk_Window tkwin) /* Tk's structure for a container or embedded
* window. */
{
Container *containerPtr;
@@ -666,15 +666,15 @@ Tk_GetOtherWindow(
* process...
*/
- if (!(((TkWindow *)winPtr)->flags & TK_BOTH_HALVES)) {
+ if (!(((TkWindow *)tkwin)->flags & TK_BOTH_HALVES)) {
return NULL;
}
for (containerPtr = firstContainerPtr; containerPtr != NULL;
containerPtr = containerPtr->nextPtr) {
- if ((Tk_Window)containerPtr->embeddedPtr == winPtr) {
+ if ((Tk_Window)containerPtr->embeddedPtr == tkwin) {
return (Tk_Window)containerPtr->parentPtr;
- } else if ((Tk_Window)containerPtr->parentPtr == winPtr) {
+ } else if ((Tk_Window)containerPtr->parentPtr == tkwin) {
return (Tk_Window)containerPtr->embeddedPtr;
}
}
@@ -644,7 +644,7 @@ TkpRedirectKeyEvent(
*
* Results:
- * If winPtr is a container, the return value is the token for the
+ * If tkwin is a container, the return value is the token for the
* embedded window, and vice versa. If the "other" window isn't in this
* process, NULL is returned.